BarterAds class

Entry point for configuring the BarterAds SDK from Flutter.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

initialize({required String appId, bool storageAllowed = true, bool personalizationAllowed = true, bool measurementAllowed = true, bool debug = false, int timeoutMs = 5000}) Future<void>
Initializes BarterAds before rendering ad widgets.