initialize static method
Initializes BarterAds before rendering ad widgets.
Call this once during app startup with the app identifier supplied by BarterAds. Consent flags are forwarded to the native Android SDK.
Implementation
static Future<void> initialize({
required String appId,
bool storageAllowed = true,
bool personalizationAllowed = true,
bool measurementAllowed = true,
bool debug = false,
int timeoutMs = 5000,
}) {
return BarteradsFlutterPlatform.instance.initialize(
appId: appId,
storageAllowed: storageAllowed,
personalizationAllowed: personalizationAllowed,
measurementAllowed: measurementAllowed,
debug: debug,
timeoutMs: timeoutMs,
);
}