BarterAdFailureCode enum

Failure codes reported by the native BarterAds SDK.

Inheritance
Available extensions

Values

missingContext → const BarterAdFailureCode

Required placement or app context was missing.

const BarterAdFailureCode('MISSING_CONTEXT')
missingClickContext → const BarterAdFailureCode

Required click context was missing.

const BarterAdFailureCode('MISSING_CLICK_CONTEXT')
networkError → const BarterAdFailureCode

The ad request failed because of a network issue.

const BarterAdFailureCode('NETWORK_ERROR')
timeout → const BarterAdFailureCode

The ad request timed out.

const BarterAdFailureCode('TIMEOUT')
invalidResponse → const BarterAdFailureCode

The native SDK received an invalid response.

const BarterAdFailureCode('INVALID_RESPONSE')
renderError → const BarterAdFailureCode

The native SDK failed to render the ad.

const BarterAdFailureCode('RENDER_ERROR')
destroyed → const BarterAdFailureCode

The banner was destroyed before the operation completed.

const BarterAdFailureCode('DESTROYED')
internalError → const BarterAdFailureCode

The native SDK reported an internal error.

const BarterAdFailureCode('INTERNAL_ERROR')
unknown → const BarterAdFailureCode

Unknown or unmapped native failure code.

const BarterAdFailureCode('UNKNOWN')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeValue String
Native Android SDK failure code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromNative(String? value) BarterAdFailureCode
Converts a native Android SDK failure value to a Flutter enum value.

Constants

values → const List<BarterAdFailureCode>
A constant List of the values in this enum, in order of their declaration.