BarterAdSize enum

Banner sizes supported by the BarterAds SDK.

Inheritance
Available extensions

Values

responsive → const BarterAdSize

Responsive banner size selected by the native SDK.

const BarterAdSize('RESPONSIVE', 50)
mobileBanner → const BarterAdSize

Standard mobile banner.

const BarterAdSize('MOBILE_BANNER', 50)
largeMobileBanner → const BarterAdSize

Larger mobile banner.

const BarterAdSize('LARGE_MOBILE_BANNER', 100)
mobileRectangle → const BarterAdSize

Mobile rectangle banner.

const BarterAdSize('MOBILE_RECTANGLE', 250)

Properties

defaultHeight double
Default Flutter layout height for this size.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
nativeValue String
Native Android SDK size value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BarterAdSize>
A constant List of the values in this enum, in order of their declaration.